require 'rails_helper'

# exemple d'utilisation
=begin
hr = Hermes::HousingRequest.first
ho= Hermes::HousingOffer.first
so=Hermes::BoClient::UpdateStatusTask.new({:'housing_request_id'=> hr.id,housing_offer_id: ho.id})
so.to_xml
so.execute
=end

dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'StatutOffre.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::OfferStatusTask, type: :helper do
  
  let!(:xsd) {Nokogiri::XML::Schema(File.read(schema_path))}
  let!(:user1) {create(:user)}
  
  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end
  
  context 'with simple housing_offer' do
    let!(:housing_offer1) do
      create(
          :housing_offer,
          offer_status: 'T2',
          external_ref: 'blabli'
      )
    end
    
    let!(:offer_status_task1) do
      build(
          :offer_status_task,
          options: { housing_offer_id: housing_offer1.id}
      )
    end
    
    describe 'using to_xml' do
      it 'should return a valid xml' do
        puts offer_status_task1.to_xml
        expect(xsd.validate(Nokogiri::XML(offer_status_task1.to_xml))).to be_present
      end
    end
  end
end